@@ -21,10 +21,10 @@
 
 use std::cmp::Ordering;
 use std::collections::HashSet;
-use std::ffi::OsString;
 use std::fmt::Display;
 use std::fs::read_to_string;
 use std::fs::File;
+use std::path::Path;
 use std::process::exit;
 use std::{io::prelude::*, str};
 
@@ -73,11 +73,9 @@ impl Category {
             .parse::<f32>()
             .map_err(|err| format!("Could not parse probability: {} at\n{}", err, line))?;
 
-        assert!(
-            (0.0..=1.0).contains(&probability),
-            "Probability {} outside 0..=1",
-            probability
-        );
+        if !(0.0..=1.0).contains(&probability) {
+            return Err(format!("Probability {} outside 0..=1", probability));
+        }
 
         Ok(Self {
             name: String::from(name),
@@ -180,7 +178,7 @@ impl Task {
 /// # Errors
 /// Returns an error when the file has invalid syntax
 #[allow(clippy::missing_panics_doc)]
-pub fn read(file: &OsString) -> Result<(Vec<Task>, Vec<Category>), String> {
+pub fn read(file: &Path) -> Result<(Vec<Task>, Vec<Category>), String> {
     let mut categories = vec![];
     let mut tasks = vec![];
     let text = read_to_string(file).expect("Could not read file");
@@ -274,10 +272,10 @@ pub fn display(categories: &[Category], mut tasks: Vec<Task>, probability: bool)
 /// Returns errors when
 /// 1) File has invalid syntax
 /// 2) Alternate buffer can't be flushed
-pub fn edit_mode(file: OsString) -> Result<(), String> {
+pub fn edit_mode(file: &Path) -> Result<(), String> {
     let mut screen = AlternateScreen::from(std::io::stdout());
     clear();
-    let (mut tasks, mut categories) = read(&file)?;
+    let (mut tasks, mut categories) = read(file)?;
     loop {
         match get_choices(&["Category", "Task"]) {
             1 => {
@@ -401,7 +399,7 @@ fn edit_tasks(tasks: &mut Vec<Task>, categories: &[Category]) {
 
         3 => {
             clear();
-            color_print(Color::Red, &format!("Deleting the task you choose"));
+            color_print(Color::Red, "Deleting the task you choose");
             let task_names = get_task_names(tasks);
             let task_index = get_choices(&task_names) - 1;
             clear();
@@ -414,7 +412,7 @@ fn edit_tasks(tasks: &mut Vec<Task>, categories: &[Category]) {
 
 /// # Panics
 /// Panics when the file cannot be opened in write mode
-fn save(categories: &[Category], tasks: &[Task], file: OsString) {
+fn save(categories: &[Category], tasks: &[Task], file: &Path) {
     let mut out = File::create(file).unwrap();
     for category in categories {
         writeln!(
@@ -523,27 +521,14 @@ pub trait HandleErr {
 impl<T, E: Display> HandleErr for Result<T, E> {
     type Inner = T;
     fn ok_or_exit(self) -> T {
-        let mut color_stream = StandardStream::stdout(Auto);
-        color_stream
-            .set_color(ColorSpec::new().set_fg(Some(Color::Red)))
-            .ok();
-
-        let ret = match self {
-            Ok(ok) => ok,
-            Err(e) => {
-                writeln!(color_stream, "{}", e).ok();
-                exit(1);
-            }
-        };
-
-        color_stream
-            .set_color(ColorSpec::new().set_fg(Some(Color::White)))
-            .ok();
-        ret
+        self.unwrap_or_else(|err| {
+            color_print(Color::Red, &err.to_string());
+            exit(1);
+        })
     }
 }
 
-fn color_print(color: Color, text: &str) {
+pub fn color_print(color: Color, text: &str) {
     let mut color_stream = StandardStream::stdout(Auto);
     color_stream
         .set_color(ColorSpec::new().set_fg(Some(color)))
