@@ -17,7 +17,8 @@
   along with todo-cras.  If not, see <https://www.gnu.org/licenses/>.
 */
 
-use todo_cras::{HandleErr, display, edit_mode, help, read};
+use std::path::PathBuf;
+use todo_cras::{color_print, display, edit_mode, help, read, HandleErr};
 
 use home::home_dir;
 
@@ -25,16 +26,19 @@ fn main() {
     let mut args = std::env::args();
     args.next();
 
-    let file = std::env::var_os("TODO_FILE").map_or_else(
-        || home_dir().unwrap().join("todo.txt").into_os_string(),
-        |var| var,
-    );
+    let file = std::env::var_os("TODO_FILE")
+        .map_or_else(|| home_dir().unwrap().join("todo.txt"), PathBuf::from);
+
+    if !file.exists() {
+        color_print(termcolor::Color::Red, "TODO_FILE does not exist");
+        return ();
+    }
 
     if let Some(arg) = args.next() {
         match arg.as_str() {
             // Edit mode.
             "-e" => {
-                edit_mode(file).ok_or_exit();
+                edit_mode(&file).ok_or_exit();
             }
 
             // Display mode, with probability. Useful as shell greeting.
